<?php
function _updateSelectionDates(&$tof,$vars) {
	require_once("actions/updateDates.php");
	$overwrite = $vars['Overwrite'];
	$tof->log("updateSelectionDates");
	list($count,$selection) = $tof->ct->getSelectedPictures($tof->uid);
	foreach($selection as $picture) {
		updateDate($tof,$picture,$overwrite);
	}
}
?>